@@ -44,6 +44,7 @@ from a2a.types import (
     UnsupportedOperationError,
 )
 from a2a.utils.errors import ServerError
+from a2a.utils.task import apply_history_length
 from a2a.utils.telemetry import SpanKind, trace_class
 
 
@@ -67,6 +68,7 @@ class DefaultRequestHandler(RequestHandler):
     """
 
     _running_agents: dict[str, asyncio.Task]
+    _background_tasks: set[asyncio.Task]
 
     def __init__(  # noqa: PLR0913
         self,
@@ -102,6 +104,9 @@ class DefaultRequestHandler(RequestHandler):
         # TODO: Likely want an interface for managing this, like AgentExecutionManager.
         self._running_agents = {}
         self._running_agents_lock = asyncio.Lock()
+        # Tracks background tasks (e.g., deferred cleanups) to avoid orphaning
+        # asyncio tasks and to surface unexpected exceptions.
+        self._background_tasks = set()
 
     async def on_get_task(
         self,
@@ -114,25 +119,7 @@ class DefaultRequestHandler(RequestHandler):
             raise ServerError(error=TaskNotFoundError())
 
         # Apply historyLength parameter if specified
-        if params.history_length is not None and task.history:
-            # Limit history to the most recent N messages
-            limited_history = (
-                task.history[-params.history_length :]
-                if params.history_length > 0
-                else []
-            )
-            # Create a new task instance with limited history
-            task = Task(
-                id=task.id,
-                context_id=task.context_id,
-                status=task.status,
-                artifacts=task.artifacts,
-                history=limited_history,
-                metadata=task.metadata,
-                kind=task.kind,
-            )
-
-        return task
+        return apply_history_length(task, params.history_length)
 
     async def on_cancel_task(
         self, params: TaskIdParams, context: ServerCallContext | None = None
@@ -310,7 +297,7 @@ class DefaultRequestHandler(RequestHandler):
         result (Task or Message).
         """
         (
-            task_manager,
+            _task_manager,
             task_id,
             queue,
             result_aggregator,
@@ -340,28 +327,32 @@ class DefaultRequestHandler(RequestHandler):
                 blocking=blocking,
                 event_callback=push_notification_callback,
             )
-            if not result:
-                raise ServerError(error=InternalError())  # noqa: TRY301
-
-            if isinstance(result, Task):
-                self._validate_task_id_match(task_id, result.id)
-
-            await self._send_push_notification_if_needed(
-                task_id, result_aggregator
-            )
 
         except Exception:
             logger.exception('Agent execution failed')
             raise
         finally:
             if interrupted_or_non_blocking:
-                # TODO: Track this disconnected cleanup task.
-                asyncio.create_task(  # noqa: RUF006
+                cleanup_task = asyncio.create_task(
                     self._cleanup_producer(producer_task, task_id)
                 )
+                cleanup_task.set_name(f'cleanup_producer:{task_id}')
+                self._track_background_task(cleanup_task)
             else:
                 await self._cleanup_producer(producer_task, task_id)
 
+        if not result:
+            raise ServerError(error=InternalError())
+
+        if isinstance(result, Task):
+            self._validate_task_id_match(task_id, result.id)
+            if params.configuration:
+                result = apply_history_length(
+                    result, params.configuration.history_length
+                )
+
+        await self._send_push_notification_if_needed(task_id, result_aggregator)
+
         return result
 
     async def on_message_send_stream(
@@ -375,16 +366,16 @@ class DefaultRequestHandler(RequestHandler):
         by the agent.
         """
         (
-            task_manager,
+            _task_manager,
             task_id,
             queue,
             result_aggregator,
             producer_task,
         ) = await self._setup_message_execution(params, context)
+        consumer = EventConsumer(queue)
+        producer_task.add_done_callback(consumer.agent_task_callback)
 
         try:
-            consumer = EventConsumer(queue)
-            producer_task.add_done_callback(consumer.agent_task_callback)
             async for event in result_aggregator.consume_and_emit(consumer):
                 if isinstance(event, Task):
                     self._validate_task_id_match(task_id, event.id)
@@ -393,8 +384,20 @@ class DefaultRequestHandler(RequestHandler):
                     task_id, result_aggregator
                 )
                 yield event
+        except (asyncio.CancelledError, GeneratorExit):
+            # Client disconnected: continue consuming and persisting events in the background
+            bg_task = asyncio.create_task(
+                result_aggregator.consume_all(consumer)
+            )
+            bg_task.set_name(f'background_consume:{task_id}')
+            self._track_background_task(bg_task)
+            raise
         finally:
-            await self._cleanup_producer(producer_task, task_id)
+            cleanup_task = asyncio.create_task(
+                self._cleanup_producer(producer_task, task_id)
+            )
+            cleanup_task.set_name(f'cleanup_producer:{task_id}')
+            self._track_background_task(cleanup_task)
 
     async def _register_producer(
         self, task_id: str, producer_task: asyncio.Task
@@ -403,6 +406,29 @@ class DefaultRequestHandler(RequestHandler):
         async with self._running_agents_lock:
             self._running_agents[task_id] = producer_task
 
+    def _track_background_task(self, task: asyncio.Task) -> None:
+        """Tracks a background task and logs exceptions on completion.
+
+        This avoids unreferenced tasks (and associated lint warnings) while
+        ensuring any exceptions are surfaced in logs.
+        """
+        self._background_tasks.add(task)
+
+        def _on_done(completed: asyncio.Task) -> None:
+            try:
+                # Retrieve result to raise exceptions, if any
+                completed.result()
+            except asyncio.CancelledError:
+                name = completed.get_name()
+                logger.debug('Background task %s cancelled', name)
+            except Exception:
+                name = completed.get_name()
+                logger.exception('Background task %s failed', name)
+            finally:
+                self._background_tasks.discard(completed)
+
+        task.add_done_callback(_on_done)
+
     async def _cleanup_producer(
         self,
         producer_task: asyncio.Task,
