@@ -183,15 +183,6 @@ class JSONRPCHandler:
             task = await self.request_handler.on_cancel_task(
                 request.params, context
             )
-            if task:
-                return prepare_response_object(
-                    request.id,
-                    task,
-                    (Task,),
-                    CancelTaskSuccessResponse,
-                    CancelTaskResponse,
-                )
-            raise ServerError(error=TaskNotFoundError())  # noqa: TRY301
         except ServerError as e:
             return CancelTaskResponse(
                 root=JSONRPCErrorResponse(
@@ -199,6 +190,19 @@ class JSONRPCHandler:
                 )
             )
 
+        if task:
+            return prepare_response_object(
+                request.id,
+                task,
+                (Task,),
+                CancelTaskSuccessResponse,
+                CancelTaskResponse,
+            )
+
+        return CancelTaskResponse(
+            root=JSONRPCErrorResponse(id=request.id, error=TaskNotFoundError())
+        )
+
     async def on_resubscribe_to_task(
         self,
         request: TaskResubscriptionRequest,
@@ -335,15 +339,6 @@ class JSONRPCHandler:
             task = await self.request_handler.on_get_task(
                 request.params, context
             )
-            if task:
-                return prepare_response_object(
-                    request.id,
-                    task,
-                    (Task,),
-                    GetTaskSuccessResponse,
-                    GetTaskResponse,
-                )
-            raise ServerError(error=TaskNotFoundError())  # noqa: TRY301
         except ServerError as e:
             return GetTaskResponse(
                 root=JSONRPCErrorResponse(
@@ -351,6 +346,19 @@ class JSONRPCHandler:
                 )
             )
 
+        if task:
+            return prepare_response_object(
+                request.id,
+                task,
+                (Task,),
+                GetTaskSuccessResponse,
+                GetTaskResponse,
+            )
+
+        return GetTaskResponse(
+            root=JSONRPCErrorResponse(id=request.id, error=TaskNotFoundError())
+        )
+
     async def list_push_notification_config(
         self,
         request: ListTaskPushNotificationConfigRequest,
