@@ -18,9 +18,9 @@ logger = logging.getLogger(__name__)
 
 
 # Regexp patterns for matching
-_TASK_NAME_MATCH = re.compile(r'tasks/([\w-]+)')
+_TASK_NAME_MATCH = re.compile(r'tasks/([^/]+)')
 _TASK_PUSH_CONFIG_NAME_MATCH = re.compile(
-    r'tasks/([\w-]+)/pushNotificationConfigs/([\w-]+)'
+    r'tasks/([^/]+)/pushNotificationConfigs/([^/]+)'
 )
 
 
@@ -46,6 +46,86 @@ def dict_to_struct(dictionary: dict[str, Any]) -> struct_pb2.Struct:
     return struct
 
 
+def make_dict_serializable(value: Any) -> Any:
+    """Dict pre-processing utility: converts non-serializable values to serializable form.
+
+    Use this when you want to normalize a dictionary before dict->Struct conversion.
+
+    Args:
+        value: The value to convert.
+
+    Returns:
+        A serializable value.
+    """
+    if isinstance(value, (str, int, float, bool)) or value is None:
+        return value
+    if isinstance(value, dict):
+        return {k: make_dict_serializable(v) for k, v in value.items()}
+    if isinstance(value, list | tuple):
+        return [make_dict_serializable(item) for item in value]
+    return str(value)
+
+
+def normalize_large_integers_to_strings(
+    value: Any, max_safe_digits: int = 15
+) -> Any:
+    """Integer preprocessing utility: converts large integers to strings.
+
+    Use this when you want to convert large integers to strings considering
+    JavaScript's MAX_SAFE_INTEGER (2^53 - 1) limitation.
+
+    Args:
+        value: The value to convert.
+        max_safe_digits: Maximum safe integer digits (default: 15).
+
+    Returns:
+        A normalized value.
+    """
+    max_safe_int = 10**max_safe_digits - 1
+
+    def _normalize(item: Any) -> Any:
+        if isinstance(item, int) and abs(item) > max_safe_int:
+            return str(item)
+        if isinstance(item, dict):
+            return {k: _normalize(v) for k, v in item.items()}
+        if isinstance(item, list | tuple):
+            return [_normalize(i) for i in item]
+        return item
+
+    return _normalize(value)
+
+
+def parse_string_integers_in_dict(value: Any, max_safe_digits: int = 15) -> Any:
+    """String post-processing utility: converts large integer strings back to integers.
+
+    Use this when you want to restore large integer strings to integers
+    after Struct->dict conversion.
+
+    Args:
+        value: The value to convert.
+        max_safe_digits: Maximum safe integer digits (default: 15).
+
+    Returns:
+        A parsed value.
+    """
+    if isinstance(value, dict):
+        return {
+            k: parse_string_integers_in_dict(v, max_safe_digits)
+            for k, v in value.items()
+        }
+    if isinstance(value, list | tuple):
+        return [
+            parse_string_integers_in_dict(item, max_safe_digits)
+            for item in value
+        ]
+    if isinstance(value, str):
+        # Handle potential negative numbers.
+        stripped_value = value.lstrip('-')
+        if stripped_value.isdigit() and len(stripped_value) > max_safe_digits:
+            return int(value)
+    return value
+
+
 class ToProto:
     """Converts Python types to proto types."""
 
@@ -73,11 +153,19 @@ class ToProto:
     @classmethod
     def part(cls, part: types.Part) -> a2a_pb2.Part:
         if isinstance(part.root, types.TextPart):
-            return a2a_pb2.Part(text=part.root.text)
+            return a2a_pb2.Part(
+                text=part.root.text, metadata=cls.metadata(part.root.metadata)
+            )
         if isinstance(part.root, types.FilePart):
-            return a2a_pb2.Part(file=cls.file(part.root.file))
+            return a2a_pb2.Part(
+                file=cls.file(part.root.file),
+                metadata=cls.metadata(part.root.metadata),
+            )
         if isinstance(part.root, types.DataPart):
-            return a2a_pb2.Part(data=cls.data(part.root.data))
+            return a2a_pb2.Part(
+                data=cls.data(part.root.data),
+                metadata=cls.metadata(part.root.metadata),
+            )
         raise ValueError(f'Unsupported part type: {part.root}')
 
     @classmethod
@@ -491,6 +579,7 @@ class FromProto:
             task_id=message.task_id or None,
             role=cls.role(message.role),
             metadata=cls.metadata(message.metadata),
+            extensions=list(message.extensions) or None,
         )
 
     @classmethod
@@ -502,11 +591,32 @@ class FromProto:
     @classmethod
     def part(cls, part: a2a_pb2.Part) -> types.Part:
         if part.HasField('text'):
-            return types.Part(root=types.TextPart(text=part.text))
+            return types.Part(
+                root=types.TextPart(
+                    text=part.text,
+                    metadata=cls.metadata(part.metadata)
+                    if part.metadata
+                    else None,
+                ),
+            )
         if part.HasField('file'):
-            return types.Part(root=types.FilePart(file=cls.file(part.file)))
+            return types.Part(
+                root=types.FilePart(
+                    file=cls.file(part.file),
+                    metadata=cls.metadata(part.metadata)
+                    if part.metadata
+                    else None,
+                ),
+            )
         if part.HasField('data'):
-            return types.Part(root=types.DataPart(data=cls.data(part.data)))
+            return types.Part(
+                root=types.DataPart(
+                    data=cls.data(part.data),
+                    metadata=cls.metadata(part.metadata)
+                    if part.metadata
+                    else None,
+                ),
+            )
         raise ValueError(f'Unsupported part type: {part}')
 
     @classmethod
